Module block_store

Module block_store 

Structs

DeviceBlockStore
Block-device-backed block store for raw devices such as EBS volumes.
DiskBlockStore
File-backed block store. Uses a regular file as a virtual block device.
MemoryBlockStore
Simple in-memory block store for testing and development.

Traits

BlockStore
Trait for a fixed-size block store backend. All blocks are the same size. Block IDs are u64.