Structs
- ChaCha
Engine - ChaCha20-Poly1305 based crypto engine. Derives the actual encryption key from a master key using HKDF.
Traits
- Crypto
Engine - Trait for encrypting and decrypting logical object payloads.
Functions
- decrypt_
object - Decrypt an EncryptedObject envelope back to plaintext bytes.
- derive_
auth_ token - Derive a 32-byte auth token from a master key using HKDF-SHA256.
- encrypt_
object - Encrypt a logical object payload into an EncryptedObject envelope.