pub struct ExtentEntry {
pub chunk_index: u64,
pub data_ref: ObjectRef,
pub plaintext_len: u32,
}Expand description
Maps a logical file chunk index to a block containing the encrypted data chunk.
Fields
chunk_index: u64Chunk index (0-based).
data_ref: ObjectRefReference to the block containing the encrypted file data chunk.
plaintext_len: u32Size of the plaintext data in this chunk.