Module proto

Module proto 

Protobuf types for the doublecrypt block-store protocol.

These are hand-written prost structs matching proto/blockstore.proto. They are wire-compatible with the length-prefixed protobuf protocol used by doublecrypt-server and can be imported directly by both the client (NetworkBlockStore) and the server, avoiding any need for protoc or prost-build.

Usage from doublecrypt-server

[dependencies]
doublecrypt-core = { version = "0.1", default-features = false }
use doublecrypt_core::proto::{Request, Response, request, response};

Modules

request
response

Structs

AuthenticateRequest
AuthenticateResponse
ErrorResponse
GetInfoRequest
GetInfoResponse
ReadBlockRequest
ReadBlockResponse
Request
Response
SyncRequest
SyncResponse
WriteBlockRequest
WriteBlockResponse