Module codec

Module codec 

Structs

PostcardCodec
Postcard-based codec (compact binary serialization).

Traits

ObjectCodec
Trait for serializing and deserializing logical objects to/from bytes.

Functions

read_encrypted_object
High-level helper: read a block, extract envelope, decrypt, deserialize.
read_encrypted_raw
Read and decrypt raw bytes (for file data chunks).
write_encrypted_object
High-level helper: serialize a typed object, encrypt it, pad to block size, and write.
write_encrypted_raw
Write raw encrypted bytes (for file data chunks that are already raw bytes).