#[unsafe(no_mangle)]pub unsafe extern "C" fn fs_destroy(handle: *mut FsHandle)Expand description
Destroy a filesystem handle and free all associated resources.
Safety
handle must be a valid pointer returned by fs_create or fs_create_disk,
and must not be used after this call.